ExtendedEOF
===========

.. currentmodule:: xeofs.single

.. autoclass:: ExtendedEOF
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ExtendedEOF.__init__
      ~ExtendedEOF.components
      ~ExtendedEOF.compute
      ~ExtendedEOF.deserialize
      ~ExtendedEOF.explained_variance
      ~ExtendedEOF.explained_variance_ratio
      ~ExtendedEOF.fit
      ~ExtendedEOF.fit_transform
      ~ExtendedEOF.get_params
      ~ExtendedEOF.get_serialization_attrs
      ~ExtendedEOF.inverse_transform
      ~ExtendedEOF.load
      ~ExtendedEOF.save
      ~ExtendedEOF.scores
      ~ExtendedEOF.serialize
      ~ExtendedEOF.singular_values
      ~ExtendedEOF.transform
   
   

   
   
   